package extThopt;

import extThopt.*;

public class BasicLiquid extends extThopt.ExtSubstance implements Inversable
{
	double aCv=0.00323208791208794,bCv=3.64034945054945;//valeurs du Cp [kJ/(kg K)], fonction affine Cp=a*t+b avec t=T-273.15
	double cV=-0.00211868131868184,aV=-0.428065934065913,bV=1044.78120879121;//valeurs du volume [m^3/kg], fonction parabolique inverse V=1/(c*t*t+a*t+b) avec t=T-273.15
    double cVisc=0.766056428571428,aVisc=-61.9573173076923,bVisc=1379.91400549451,dVisc=0.;//valeurs de la viscosit [10^-5 Pas], fonction mu=d/T+c*t*t+a*t+b avec t=T-273.15
    double aCond=0.000754285714285715,bCond=0.384457142857143,cCond=0.;//valeurs de la conductivit [W/(m K)], fonction parabolique lambda=c*t*t+a*t+b avec t=T-273.15
    
    public BasicLiquid (){
        super();
        type=getType();
        M=29;PC=10;TC=350; 
        Tmini=258.15;  Tmaxi=333.15; 
        chemForm="propylene glycol 40% vol";
    }
    
    public String getCompType(){
        return "prop. glycol water 40%";
    }
    public String getType(){
        return getCompType();
    }
    	public String getClassDescription(){
	    return "data from ASHRAE\n\nauthor : R. Gicquel   march 2003";
	}

    
	public double getT_from_hP(double $h,double $P){
        double T=Util.dicho_T (this,$h,$P, "calcH",Tmini, Tmaxi,0.0001);
        return T;
	}
  
	public double getT_from_sP(double $s,double $P){
        double T=Util.dicho_T (this,$s,$P, "calcS",Tmini, Tmaxi,0.000001);
        return T;
	}
    
	public double f_dicho(double X, double P,String fonc){
        
        if (fonc.equals("calcS"))return calcS(X, P, 0);
        if (fonc.equals("calcH"))return calcH(X, P, 0);
        return 0;
    }
    
	public double calcH (double T, double P,double x) {
        double V=calcV(T, P,x);
	    double TT=T-273.15;
	    return bCv*TT+aCv/2.*TT*TT+V*(P-1)*100;
	}
	public double calcS (double T, double P,double x) {
	    double TT=T-273.15;
	    return bCv*Math.log(T/273.15)+aCv*TT;
	}
	public double calcCv (double T, double P,double x) {
	    double TT=T-273.15;
	    return (bCv+aCv*TT)*1000.;
	}
	public double calcCp (double T, double P,double x) {
	    return calcCv(T, P, x);
	}
	public double calcV (double T, double P,double x) {
	    double TT=T-273.15;
	    return 1./(cV*TT*TT+aV*TT+bV);
	}

    public double getLiquidViscosity(double T) {
	    double TT=T-273.15;
	    return (dVisc/T+cVisc*TT*TT+aVisc*TT+bVisc)/100000.;
    }
    public double getVaporViscosity(double T) {
 	    double TT=T-273.15;
	    return (dVisc/T+cVisc*TT*TT+aVisc*TT+bVisc)/100000.;
    }

    public double getLiquidConductivity(double T) {
	    double TT=T-273.15;
	    return cCond*TT*TT+aCond*TT+bCond;
    }
    public double getVaporConductivity(double T) {
	    double TT=T-273.15;
	    return cCond*TT*TT+aCond*TT+bCond;
    }  
    public double getVaporViscosity(double T, double P) {
 	    double TT=T-273.15;
	    return (dVisc/T+cVisc*TT*TT+aVisc*TT+bVisc)/100000.;
    }

    public double getLiquidConductivity(double T, double P) {
	    double TT=T-273.15;
	    return cCond*TT*TT+aCond*TT+bCond;
    }
    public double getVaporConductivity(double T, double P) {
	    double TT=T-273.15;
	    return cCond*TT*TT+aCond*TT+bCond;
    }  
    public double getLiquidViscosity(double T, double P) {
	    double TT=T-273.15;
	    return (dVisc/T+cVisc*TT*TT+aVisc*TT+bVisc)/100000.;
    }

}